@@ -134,7 +134,7 @@ use MIME::Field::ContType;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5.202 $, 10;
+$VERSION = substr q$Revision: 5.203 $, 10;
 
 ### Sanity (we put this test after our own version, for CPAN::):
 use Mail::Header 1.06 ();
@@ -679,9 +679,10 @@ C<"image/gif">, C<"x-weird-type">, which is returned in all-lowercase.
     The default Content-Type for Internet mail is 
     "text/plain; charset=us-ascii".
 
-Unless this is a part of a "message/digest", in which case "message/rfc822"
-is the default.  Note that you can also I<set> the default, but you 
-shouldn't: normally only the MIME parser uses this feature.
+Unless this is a part of a "multipart/digest", in which case 
+"message/rfc822" is the default.  Note that you can also I<set> the 
+default, but you shouldn't: normally only the MIME parser uses this 
+feature.
 
 =cut
 
@@ -874,7 +875,7 @@ Lee E. Brotzman, Advanced Data Solutions.
 
 =head1 VERSION
 
-$Revision: 5.202 $ $Date: 2000/06/05 13:37:54 $
+$Revision: 5.203 $ $Date: 2000/07/04 06:43:13 $
 
 =cut
 
